function varargout = fc9(varargin)
% FC9 M-file for fc9.fig
%      FC9, by itself, creates a new FC9 or raises the existing
%      singleton*.
%
%      H = FC9 returns the handle to a new FC9 or the handle to
%      the existing singleton*.
%
%      FC9('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in FC9.M with the given input arguments.
%
%      FC9('Property','Value',...) creates a new FC9 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before fc9_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to fc9_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help fc9

% Last Modified by GUIDE v2.5 14-Jan-2009 10:52:34

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @fc9_OpeningFcn, ...
                   'gui_OutputFcn',  @fc9_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before fc9 is made visible.
function fc9_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to fc9 (see VARARGIN)

% Choose default command line output for fc9
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes fc9 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = fc9_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function ftemp_Callback(hObject, eventdata, handles)
% hObject    handle to ftemp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of ftemp as text
%        str2double(get(hObject,'String')) returns contents of ftemp as a double
str = get(handles.ftemp, 'string');
f = str2num(str);
if isempty(f) error('Formatfel'); return; end
c = (f-32)*5/9;
set(handles.ctemp,'string',num2str(c,'%6.1f'));
s = get(handles.logg,'string');
si = size(s); n =5;
if si(1)>=n
    set(handles.logg,'string',s(2:end,:));
end
set(handles.logg,'string',char(get(handles.logg,'string'),...
    [num2str(f,'%6.1f') ' F = ' num2str(c,'%6.1f') ' C']));


% --- Executes during object creation, after setting all properties.
function ftemp_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ftemp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function ctemp_Callback(hObject, eventdata, handles)
% hObject    handle to ctemp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of ctemp as text
%        str2double(get(hObject,'String')) returns contents of ctemp as a double
str = get(handles.ctemp,'string');
c = str2num(str);
if isempty(c) error('Formatfel'); return; end
f = c*9/5+32;
set(handles.ftemp,'string',num2str(f,'%6.1f'));
s = get(handles.logg,'string');
si = size(s); n = 5;
if si(1)>=n
    set(handles.logg, 'string',s(2:end,:));
end
set(handles.logg,'string',char(get(handles.logg,'string'),...
    [num2str(c,'%6.1f') ' C = ' num2str(f,'%6.1f') ' F']));

% --- Executes during object creation, after setting all properties.
function ctemp_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ctemp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in avsluta.
function avsluta_Callback(hObject, eventdata, handles)
% hObject    handle to avsluta (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close(fc9);

